@@ -271,9 +271,9 @@ SoRenderManager::SoRenderManager(void)
   PRIVATE(this)->glaction = new SoGLRenderAction(SbViewportRegion(400, 400));
   PRIVATE(this)->audiorenderaction = new SoAudioRenderAction;
 
-  PRIVATE(this)->clipsensor =
-    new SoNodeSensor(SoRenderManagerP::updateClippingPlanesCB, PRIVATE(this));
-  PRIVATE(this)->clipsensor->setPriority(this->getRedrawPriority() - 1);
+  PRIVATE(this)->clipsensor = NULL;
+  //  new SoNodeSensor(SoRenderManagerP::updateClippingPlanesCB, PRIVATE(this));
+  //PRIVATE(this)->clipsensor->setPriority(this->getRedrawPriority() - 1);
 
 }
 
@@ -296,7 +296,7 @@ SoRenderManager::~SoRenderManager()
     delete PRIVATE(this)->superimpositions;
   }
 
-  delete PRIVATE(this)->clipsensor;
+  //delete PRIVATE(this)->clipsensor;
 
   if (PRIVATE(this)->scene)
     PRIVATE(this)->scene->unref();
@@ -316,7 +316,7 @@ SoRenderManager::~SoRenderManager()
 void
 SoRenderManager::setSceneGraph(SoNode * const sceneroot)
 {
-  this->detachClipSensor();
+  //this->detachClipSensor();
   this->detachRootSensor();
   // Don't unref() until after we've set up the new root, in case the
   // old root == the new sceneroot. (Just to be that bit more robust.)
@@ -327,7 +327,7 @@ SoRenderManager::setSceneGraph(SoNode * const sceneroot)
   if (PRIVATE(this)->scene) {
     PRIVATE(this)->scene->ref();
     this->attachRootSensor(PRIVATE(this)->scene);
-    this->attachClipSensor(PRIVATE(this)->scene);
+    //this->attachClipSensor(PRIVATE(this)->scene);
   }
   
   if (oldroot) oldroot->unref();
@@ -426,31 +426,31 @@ SoRenderManager::detachRootSensor(void)
 
   \param[in] sceneroot scene to attach to
 
-  \deprecated Will not be available in Coin 4
+  \deprecated Will not be available in Coin 5
 */
 void
 SoRenderManager::attachClipSensor(SoNode * const sceneroot)
 {
-  PRIVATE(this)->clipsensor->attach(sceneroot);
-  if (PRIVATE(this)->autoclipping != SoRenderManager::NO_AUTO_CLIPPING) {
-    PRIVATE(this)->clipsensor->schedule();
-  }
+  //PRIVATE(this)->clipsensor->attach(sceneroot);
+  //if (PRIVATE(this)->autoclipping != SoRenderManager::NO_AUTO_CLIPPING) {
+  //  PRIVATE(this)->clipsensor->schedule();
+  //}
 }
 
 /*
   Detaches the clipsensor from all tracked scenes
 
-  \deprecated Will not be available in Coin 4
+  \deprecated Will not be available in Coin 5
 */
 void
 SoRenderManager::detachClipSensor(void)
 {
-  if (PRIVATE(this)->clipsensor->isScheduled()) {
-    PRIVATE(this)->clipsensor->unschedule();
-  }
-  if (PRIVATE(this)->clipsensor->getAttachedNode()) {
-    PRIVATE(this)->clipsensor->detach();
-  }
+  //if (PRIVATE(this)->clipsensor->isScheduled()) {
+  //  PRIVATE(this)->clipsensor->unschedule();
+  //}
+  //if (PRIVATE(this)->clipsensor->getAttachedNode()) {
+  //  PRIVATE(this)->clipsensor->detach();
+  //}
 }
 
 /*!
@@ -779,6 +779,11 @@ SoRenderManager::renderScene( SoGLRenderAction * action,
     // This callback is removed again in the prerendercb function
     action->addPreRenderCallback(this->prerendercb, (void*) (uintptr_t) clearmask);
   }
+
+  if (PRIVATE(this)->autoclipping != SoRenderManager::NO_AUTO_CLIPPING) {
+    PRIVATE(this)->setClippingPlanes();
+  }
+
   action->apply(scene);
 }
 
@@ -979,20 +984,20 @@ SoRenderManager::setAutoClipping(AutoClippingStrategy autoclipping)
 {
   PRIVATE(this)->autoclipping = autoclipping;
 
-  if (PRIVATE(this)->scene) {
-    switch (autoclipping) {
-    case SoRenderManager::NO_AUTO_CLIPPING:
-      this->detachClipSensor();
-      break;
-    case SoRenderManager::FIXED_NEAR_PLANE:
-    case SoRenderManager::VARIABLE_NEAR_PLANE:
-      if (!PRIVATE(this)->clipsensor->getAttachedNode()) {
-        PRIVATE(this)->clipsensor->attach(PRIVATE(this)->scene);
-      }
-      PRIVATE(this)->clipsensor->schedule();
-      break;
-    }
-  }
+  //if (PRIVATE(this)->scene) {
+  //  switch (autoclipping) {
+  //  case SoRenderManager::NO_AUTO_CLIPPING:
+  //    this->detachClipSensor();
+  //    break;
+  //  case SoRenderManager::FIXED_NEAR_PLANE:
+  //  case SoRenderManager::VARIABLE_NEAR_PLANE:
+  //    if (!PRIVATE(this)->clipsensor->getAttachedNode()) {
+  //      PRIVATE(this)->clipsensor->attach(PRIVATE(this)->scene);
+  //    }
+  //    PRIVATE(this)->clipsensor->schedule();
+  //    break;
+  //  }
+  //}
 }
 
 /*!
